@@ -9,6 +9,7 @@ import requests
 import tldextract
 from loguru import logger
 from tenacity import retry, stop_after_attempt, wait_random
+from distutils.util import strtobool
 
 
 def rmdir(dir_location):
@@ -71,7 +72,7 @@ class RundeckJobs(object):
             uptimerobot_api_key: str = os.environ.get(
                 "RD_OPTION_UPTIMEROBOT_API_KEY"),
             fqdn: str = os.environ.get("RD_OPTION_FQDN"),
-            force_apply: bool = bool(os.environ.get('RD_OPTION_FORCE_APPLY'))):
+            force_apply: bool = strtobool(os.environ.get('RD_OPTION_FORCE_APPLY'))):
         if deployment_action != 'apply':
             print("Skipping website hosting check as deployment action is not apply")
             exit(0)
